@@ -59,6 +59,10 @@ for blocked_module in [
     "gdata.docs.service",
     "gdata.service",
     "types",
+    "atom.http",
+    "atom.http_interface",
+    "atom.service",
+    "atom.token_store",
     ]:
     if blocked_module not in ignore:
         ignore.append(blocked_module)
